==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/ar-SA/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'هذا المستخدم تسجيل الدخول',
    'activated_disabled_help_text' => 'لا يمكنك تعديل حالة التنشيط لحسابك الخاص.',
    'assets_user'       => 'الأصول التي تم اخراجها إلى :name',
    'bulk_update_warn'	=> 'أنت على وشك تعديل خصائص :user_count من المستخدمين. يرجى ملاحظة أنه لا يمكنك تغيير سمات المستخدم الخاصة بك باستخدام هذا النموذج، ويجب إجراء تعديلات على المستخدم الخاص بك بشكل على حدة.',
    'bulk_update_help'	=> 'يتيح لك هذا النموذج تحديث عدة مستخدمين في وقت واحد. قم بملء الحقول التي تحتاج إلى تغييرها. ستظل أية حقول فارغة فارغة دون تغيير.',
    'current_assets'    => 'يتم حاليا سحب الأصول إلى هذا المستخدم',
    'clone'             => 'نسخ المستخدم',
    'contact_user'      => 'الاتصال: :name',
    'edit'              => 'تعديل المستخدم',
    'filetype_info'     => 'انواع صيغ الملفات المسوح بها هي png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'الأرشيف الخاص بـ :name',
    'info'				=> 'معلومات',
    'restore_user'		=> 'انقر هنا لاستعادتها.',
    'last_login'        => 'آخر دخول للمستخدم',
    'ldap_config_text'  => 'يمكن العثور على إعدادات تهيئة لداب المشرف> الإعدادات. سيتم تعيين الموقع (اختياري) المحدد لجميع المستخدمين الذين تم استيرادهم.',
    'print_assigned'    => 'طباعة كل الممتلكات',
    'email_assigned'    => 'قائمة البريد اﻹلكتروني لكل المعينين',
    'user_notified'     => 'تم إرسال قائمة بالعناصر المعينة حاليا إلى المستخدم بالبريد الإلكتروني.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'تضمين هذا المستخدم عند التعيين التلقائي للتراخيص المؤهلة',
    'auto_assign_help'  => 'تخطي هذا المستخدم في التعيين التلقائي للترخيص',
    'software_user'     => 'البرامج المخرجة الى: :name',
    'send_email_help'   => 'يجب عليك توفير عنوان بريد إلكتروني لهذا المستخدم لإرسال بيانات اعتماده. لا يمكن إرسال بيانات الاعتماد البريدية إلا عند إنشاء المستخدم. يتم تخزين كلمات المرور في تجزئة ذات اتجاه واحد ولا يمكن استرجاعها بمجرد الحفظ.',
    'view_user'         => 'عرض المستخدم :name',
    'usercsv'           => 'ملف CSV',
    'two_factor_admin_optin_help' => 'تسمح إعدادات المشرف الحالية بإنفاذ انتقائي للمصادقة الثنائية.',
    'two_factor_enrolled' => '2FA الجهاز المسجلين',
    'two_factor_active'   => '2FA نشط',
    'user_deactivated'  => 'لا يمكن تسجيل المستخدم',
    'user_activated'  => 'يمكن تسجيل المستخدم',
    'activation_status_warning' => 'عدم تغيير حالة التفعيل',
    'group_memberships_helpblock' => 'فقط المشرفين العامون يمكنهم تعديل عضويات المجموعة.',
    'superadmin_permission_warning' => 'فقط للمشرفين العامين يمكنهم منح مستخدم صلاحية المشرف العام.',
    'admin_permission_warning' => 'يمكن فقط للمستخدمين الذين لديهم حقوق المشرفين أو أعلى منح صلاحية مشرف لمستخدم.',
    'remove_group_memberships' => 'إزالة عضويات مجموعة',
    'warning_deletion_information' => 'أنت على وشك تسجيل جميع العناصر من :count المستخدم (المستخدمين) المدرجة أدناه. يتم تسليط الضوء على أسماء المشرف الممتاز بالأحمر.',
    'update_user_assets_status' => 'تحديث جميع الأصول لهؤلاء المستخدمين إلى هذه الحالة',
    'checkin_user_properties' => 'تحقق من جميع الخصائص المرتبطة بهؤلاء المستخدمين',
    'remote_label'   => 'هذا مستخدم بعيد',
    'remote'   => 'عن بعد',
    'remote_help' => 'يمكن أن يكون هذا مفيداً إذا كنت بحاجة إلى التصفية بواسطة مستخدمين بعيدين لا يأتون أبداً أو نادراً إلى مواقعك الفعلية.',
    'not_remote_label' => 'هذا ليس مستخدم بعيد',
    'vip_label' => 'مستخدم VIP',
    'vip_help' => 'هذا يمكن أن يكون مفيداً لوضع علامة على أشخاص مهمين في مؤسستك إذا كنت ترغب في التعامل معهم بطرق خاصة.',
    'create_user' => 'إنشاء مستخدم',
    'create_user_page_explanation' => 'هذه هي معلومات الحساب التي ستستخدمها للوصول إلى الموقع لأول مرة.',
    'email_credentials' => 'بيانات اعتماد البريد الإلكتروني',
    'email_credentials_text' => 'إرسال بيانات اعتمادي إلى عنوان البريد الإلكتروني أعلاه',
    'next_save_user' => 'التالي : حفظ المستخدم',
    'all_assigned_list_generation' => 'تم إنشاؤها في:',
    'email_user_creds_on_create' => 'إرسال بيانات دخول هذا المستخدم بالبريد الإلكتروني؟',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/ar-SA/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'هذا المستخدم تسجيل الدخول',
    'activated_disabled_help_text' => 'لا يمكنك تعديل حالة التنشيط لحسابك الخاص.',
    'assets_user'       => 'الأصول التي تم اخراجها إلى :name',
    'bulk_update_warn'	=> 'أنت على وشك تعديل خصائص :user_count من المستخدمين. يرجى ملاحظة أنه لا يمكنك تغيير سمات المستخدم الخاصة بك باستخدام هذا النموذج، ويجب إجراء تعديلات على المستخدم الخاص بك بشكل على حدة.',
    'bulk_update_help'	=> 'يتيح لك هذا النموذج تحديث عدة مستخدمين في وقت واحد. قم بملء الحقول التي تحتاج إلى تغييرها. ستظل أية حقول فارغة فارغة دون تغيير.',
    'current_assets'    => 'يتم حاليا سحب الأصول إلى هذا المستخدم',
    'clone'             => 'نسخ المستخدم',
    'contact_user'      => 'الاتصال: :name',
    'edit'              => 'تعديل المستخدم',
    'filetype_info'     => 'انواع صيغ الملفات المسوح بها هي png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, and rar.',
    'history_user'      => 'الأرشيف الخاص بـ :name',
    'info'				=> 'معلومات',
    'restore_user'		=> 'انقر هنا لاستعادتها.',
    'last_login'        => 'آخر دخول للمستخدم',
    'ldap_config_text'  => 'يمكن العثور على إعدادات تهيئة لداب المشرف> الإعدادات. سيتم تعيين الموقع (اختياري) المحدد لجميع المستخدمين الذين تم استيرادهم.',
    'print_assigned'    => 'طباعة كل الممتلكات',
    'email_assigned'    => 'قائمة البريد اﻹلكتروني لكل المعينين',
    'user_notified'     => 'تم إرسال قائمة بالعناصر المعينة حاليا إلى المستخدم بالبريد الإلكتروني.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'تضمين هذا المستخدم عند التعيين التلقائي للتراخيص المؤهلة',
    'auto_assign_help'  => 'تخطي هذا المستخدم في التعيين التلقائي للترخيص',
    'software_user'     => 'البرامج المخرجة الى: :name',
    'view_user'         => 'عرض المستخدم :name',
    'usercsv'           => 'ملف CSV',
    'two_factor_admin_optin_help' => 'تسمح إعدادات المشرف الحالية بإنفاذ انتقائي للمصادقة الثنائية.',
    'two_factor_enrolled' => '2FA الجهاز المسجلين',
    'two_factor_active'   => '2FA نشط',
    'user_deactivated'  => 'لا يمكن تسجيل المستخدم',
    'user_activated'  => 'يمكن تسجيل المستخدم',
    'activation_status_warning' => 'عدم تغيير حالة التفعيل',
    'group_memberships_helpblock' => 'فقط المشرفين العامون يمكنهم تعديل عضويات المجموعة.',
    'superadmin_permission_warning' => 'فقط للمشرفين العامين يمكنهم منح مستخدم صلاحية المشرف العام.',
    'admin_permission_warning' => 'يمكن فقط للمستخدمين الذين لديهم حقوق المشرفين أو أعلى منح صلاحية مشرف لمستخدم.',
    'remove_group_memberships' => 'إزالة عضويات مجموعة',
    'warning_deletion_information' => 'أنت على وشك تسجيل جميع العناصر من :count المستخدم (المستخدمين) المدرجة أدناه. يتم تسليط الضوء على أسماء المشرف الممتاز بالأحمر.',
    'update_user_assets_status' => 'تحديث جميع الأصول لهؤلاء المستخدمين إلى هذه الحالة',
    'checkin_user_properties' => 'تحقق من جميع الخصائص المرتبطة بهؤلاء المستخدمين',
    'remote_label'   => 'هذا مستخدم بعيد',
    'remote'   => 'عن بعد',
    'remote_help' => 'يمكن أن يكون هذا مفيداً إذا كنت بحاجة إلى التصفية بواسطة مستخدمين بعيدين لا يأتون أبداً أو نادراً إلى مواقعك الفعلية.',
    'not_remote_label' => 'هذا ليس مستخدم بعيد',
    'vip_label' => 'مستخدم VIP',
    'vip_help' => 'هذا يمكن أن يكون مفيداً لوضع علامة على أشخاص مهمين في مؤسستك إذا كنت ترغب في التعامل معهم بطرق خاصة.',
    'create_user' => 'إنشاء مستخدم',
    'create_user_page_explanation' => 'هذه هي معلومات الحساب التي ستستخدمها للوصول إلى الموقع لأول مرة.',
    'email_credentials' => 'بيانات اعتماد البريد الإلكتروني',
    'email_credentials_text' => 'إرسال بيانات اعتمادي إلى عنوان البريد الإلكتروني أعلاه',
    'next_save_user' => 'التالي : حفظ المستخدم',
    'all_assigned_list_generation' => 'تم إنشاؤها في:',
    'email_user_creds_on_create' => 'إرسال بيانات دخول هذا المستخدم بالبريد الإلكتروني؟',
    'department_manager' => 'Department Manager',
];
